#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128
#define SCREEN_HEIGHT 32
#define OLED_RESET    -1 // No reset pin
#define OLED_ADDR     0x3C

Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

// NEW Datatype For State
enum _state { NOT_READY, READY, SENDING };

// Variables
_state  state = NOT_READY;

void setup() {

  // Serial
  Serial.begin(115200);

  // Initialize I2C bus (ESP32-C3 default pins)
  Wire.begin();

  // Scan I2C devices
  Serial.println("Scanning I2C devices...");

  // Scan I2C
  scanI2C();

  // Initialize OLED
  if(!display.begin(SSD1306_SWITCHCAPVCC, OLED_ADDR)) {
    Serial.println("SSD1306 allocation failed");
    while(1);
  }

  // Print On Display
  oled_write("Hello, ESP32-C3!");

}

void loop() {

  // Send Tex Message To Slave
  i2c_send_string(0x55, Question("String Message"));

  // Request Data
  Wire.requestFrom(0x55, 1);

  // Read Data Available
  if(Wire.available()) {
    if(char(Wire.read()) == 'N') {
      Serial.println("Requested Data : Not Ready");
      state = NOT_READY;
    } else {
      Serial.println("Requested Data : Ready");
      state = READY;
    }
  }

  // Request Data
  Wire.requestFrom(0x55, 6);

  // Prepare 6 Bytes Of Data
  uint8_t data[6];

  // Read Data Available
  if(Wire.available()) {
    for(int i=0; i<6; i++) {
      data[i] = Wire.read();
      Serial.print(char(data[i]));
    }
    Serial.println();
  }

}
